@@ -1060,3 +1060,127 @@ def LFP(data):
     df.insert(0, "Time", time, True)
 
     return df  
+
+def PlotInteraction(interactions, **kwargs):
+  """
+  Plots a bar with interactions times of the determined body with the fields.
+
+  Parameters
+  ----------
+  interactions : pandas DataFrame
+      The DataFrame with the interactions of the fields (output of Interaction()). 
+  barH : float, optional
+      Bar height.
+  start : int, optional
+      Moment of the video you want tracking to start, in seconds. If the variable 
+      is empty (None), the entire video will be processed.
+  end : int, optional
+      Moment of the video you want tracking to end, in seconds. If the variable is 
+      empty (None), the entire video will be processed.
+  fps : int
+      The recording frames per second.
+  figureTitle : str, optional
+      Figure title.
+  hSize : int, optional
+      Determine the figure height size (x).
+  wSize : int, optional
+      Determine the figure width size (y).
+  fontsize : int, optional
+      Determine of all font sizes.
+  saveName : str, optional
+      Determine the save name of the plot.        
+  figformat : str, optional
+      Determines the type of file that will be saved. Used as base the ".eps", 
+      which may be another supported by matplotlib. 
+  res : int, optional
+      Determine the resolutions (dpi), default = 80.
+  ax : fig, optional
+      Creates an 'axs' to be added to a figure created outside the role by the user.
+
+  Returns
+  -------
+  out : plot
+      The output of the function is the figure with the interactions times with fields.
+
+  See Also
+  --------
+  For more information and usage examples: https://github.com/pyratlib/pyrat
+
+  Notes
+  -----
+  This function was developed based on DLC outputs and is able to support 
+  matplotlib configurations."""
+
+    
+  import pyratlib as rat
+  import matplotlib.pyplot as plt
+
+  saveName= kwargs.get('saveName')
+  start= kwargs.get('start')
+  end= kwargs.get('end')
+  figureTitle = kwargs.get('figureTitle')
+  fps = kwargs.get('fps')
+  ax = kwargs.get('ax')
+  if type(fps) == type(None):
+    fps = 30
+  hSize = kwargs.get('hSize')
+  if type(hSize) == type(None):
+    hSize = 2
+  wSize = kwargs.get('wSize')
+  if type(wSize) == type(None):
+    wSize = 8
+  fontsize = kwargs.get('fontsize')
+  if type(fontsize) == type(None):
+    fontsize = 15
+  figformat = kwargs.get('figformat')
+  if type(figformat) == type(None):
+    figformat = '.eps'
+    res = kwargs.get('res')
+  if type(res) == type(None):
+    res = 80 
+  barH = kwargs.get('barH')
+  if type(barH) == type(None):
+    barH = .5
+
+  if type(start) == type(None):
+      init = 0
+      finish = interactions.end.iloc[-1]
+  else:
+      init = int(start)
+      finish = int(end) 
+
+  times = []
+  starts = []
+  for i in range (int(interactions.obj.max())+1):
+      times.append((interactions.end.loc[(interactions.obj == i) & (interactions.start >= init) & (interactions.start <= finish)])-(interactions.start.loc[(interactions.obj == i) & (interactions.start >= init) & (interactions.start <= finish)]).values)
+      starts.append((interactions.start.loc[(interactions.obj == i) & (interactions.start >= init) & (interactions.start <= finish)]).values)
+
+  barHeight = barH
+
+  if type(ax) == type(None):
+    plt.figure(figsize=(wSize,hSize))
+    for i in range (1,int(interactions.obj.max())+1):
+      plt.barh(0,times[i], left=starts[i], height = barHeight, label = "Field "+str(i))
+
+    plt.legend(ncol=int(interactions.obj.max()))
+    plt.xlim(init, finish)
+    plt.yticks([])
+    plt.xticks(fontsize = fontsize*0.8)
+    plt.xlabel("Time (s)",fontsize=fontsize)
+    plt.ylim([-barHeight,barHeight])
+    plt.show()
+    if type(saveName) != type(None):
+        plt.savefig(saveName+figformat)
+  else:
+    for i in range (1,int(interactions.obj.max())+1):
+      ax.barh(0,times[i], left=starts[i], height = barHeight, label = "Field "+str(i))
+    ax.set_aspect('equal')
+    ax.set_xlim([init, finish])
+    ax.set_yticklabels([])
+    ax.get_yaxis().set_visible(False)
+    ax.tick_params(axis='x', labelsize=fontsize*.8)
+    ax.tick_params(axis='y', labelsize=fontsize*.8)
+    ax.legend(ncol=int(interactions.obj.max()),fontsize=fontsize)
+    ax.set_xlabel('Time (s)',fontsize=fontsize)
+
+    ax.set_ylim([-barHeight,barHeight])
